@@ -103,8 +103,8 @@ class JManFb:
     def c_sync_transportistes(self):
         return self.select(sql=fb_consultes.sync_transportistes)
 
-    def c_sync_comandes_pendents(self):
-        return self.select(sql=fb_consultes.sync_comandes_pendents)
+    def c_sync_comandes_pendents(self, magatzem_id: int):
+        return self.select(sql=fb_consultes.sync_comandes_pendents, args=(magatzem_id,))
 
     def c_sync_magatzems_ordres_pendents(self, p_magatzem_entrada_id: int):
         return self.select(sql=fb_consultes.sync_magatzems_ordres_pendents, args=(p_magatzem_entrada_id,))
@@ -115,5 +115,5 @@ class JManFb:
     def c_sync_comanda(self, comanda_id: int):
         return self.select(sql=fb_consultes.sync_comanda, args=(comanda_id,))[0]
 
-    def c_sync_comanda_linies(self, comanda_id: int):
-        return self.select(sql=fb_consultes.sync_comanda_linies, args=(comanda_id,))
+    def c_sync_comanda_linies(self, comanda_id: int, magatzem_id: int):
+        return self.select(sql=fb_consultes.sync_comanda_linies, args=(comanda_id,magatzem_id))
