@@ -68,29 +68,37 @@ where c.ID = ?
 """
 
 sync_comanda_linies = """
-select cl_atr.ID ATRIBUT_ID, sum(cl.QUANTITAT) QUANTITAT, min(cl.NUMERO_LINIA) nl, min(cl.DESCRIPCIO), 
-sum(cl.QUANTITAT) QUANTITAT_PENDENT
-from comandes c
-join comandes_linies cl on c.ID = cl.COMANDA_ID
-join articles_atributs cl_atr on cl.ARTICLE_ATRIBUT_ID = cl_atr.ID
-join articles cl_art on cl_atr.ARTICLE_ID = cl_art.ID
-LEFT join select_articles_c_estocs(cl_art.ID, c.DATA_COMANDA) cl_art_stk on cl_art.ID =  cl_art_stk.ARTICLE_ID
-where cl_art_stk.CONTROL_ESTOCS = 'S' and c.ID = ?
-group by ATRIBUT_ID
+select cl_atr.ID ATRIBUT_ID
+     , sum(cl.QUANTITAT) QUANTITAT
+     , min(cl.NUMERO_LINIA) nl
+     , min(cl.DESCRIPCIO)
+     , sum(cl.QUANTITAT) QUANTITAT_PENDENT
+  from comandes c
+  join comandes_linies cl on c.ID = cl.COMANDA_ID
+  join articles_atributs cl_atr on cl.ARTICLE_ATRIBUT_ID = cl_atr.ID
+  join articles cl_art on cl_atr.ARTICLE_ID = cl_art.ID
+  LEFT join select_articles_c_estocs(cl_art.ID, c.DATA_COMANDA) cl_art_stk on cl_art.ID =  cl_art_stk.ARTICLE_ID
+ where cl_art_stk.CONTROL_ESTOCS = 'S' 
+   and c.ID = ?
+   and cl.magatzem_id = ?
+group by cl_atr.id
 HAVING sum(cl.QUANTITAT) > 0
 """
 
 sync_comandes_pendents = """
 SELECT C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA,C.DATA_INSERCIO,C.REFERENCIA, T.NOM_LLARG_I_COMERCIAL
-FROM COMANDES C
-JOIN CLIENTS CL ON C.CLIENT_ID = CL.ID
-JOIN TERCERS T ON CL.TERCER_ID = T.ID
-JOIN COMANDES_DISTRIBUCIO CD ON C.ID = CD.COMANDA_ID
-left join SELECT_COMANDES_ESTATS_MAG(C.ID) CE ON C.ID = CE.COMANDA_ID
-where C.DATA_INICI IS NULL 
-AND CE.MAG_PENDENT_SERVIR = 'S' 
-AND C.DATA_ANULACIO IS NULL
-and CD.REPARTIDOR_ID IS NOT NULL ;
+  FROM COMANDES C
+  JOIN CLIENTS CL ON C.CLIENT_ID = CL.ID
+  JOIN TERCERS T ON CL.TERCER_ID = T.ID
+  JOIN COMANDES_DISTRIBUCIO CD ON C.ID = CD.COMANDA_ID
+  JOIN COMANDES_LINIES CCL ON CCL.COMANDA_ID = C.ID
+  left join SELECT_COMANDES_ESTATS_MAG(C.ID) CE ON C.ID = CE.COMANDA_ID
+ where C.DATA_INICI IS NULL 
+   AND CE.MAG_PENDENT_SERVIR = 'S' 
+   AND C.DATA_ANULACIO IS NULL
+   AND CCL.MAGATZEM_ID = ?
+   and CD.REPARTIDOR_ID IS NOT NULL 
+ group by C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA,C.DATA_INSERCIO,C.REFERENCIA, T.NOM_LLARG_I_COMERCIAL;
 """
 
 sync_magatzems_ordres_pendents = """
